Clazz.declarePackage("JSV.api");
Clazz.declareInterface(JSV.api, "JSVPrintDialog");
;//5.0.1-v7 Sun Feb 08 12:09:17 CST 2026
